@@ -91,7 +91,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         list_train_recall.append(kpi["train/recall"])
         list_train_f1.append(kpi["train/f1"])
         list_train_average_precision.append(kpi["train/average_precision"])
-        list_valid_roc_auc.append(kpi["train/roc_auc"])        
+        list_train_roc_auc.append(kpi["train/roc_auc"])        
         
         
         
